@@ -3,7 +3,7 @@
 from __future__ import absolute_import, unicode_literals
 
 __author__  = 'Jefurry <jefurry@qq.com>'
-__version__ = '0.1.6'
+__version__ = '0.1.7'
 
 import traceback
 from sqlbuilder import smartsql as sb
@@ -29,6 +29,17 @@ SMARTSQL_DIALECTS = {
     'oracle': 'oracle',
 }
 
+logger = util.getLogger('pyar')
+def dumpSQL(sql, params, using='default'):
+    tpl = '''
+    --- SQL DUMP ---
+    using: {0}
+    {1} - {2}
+    --- END DUMP ---
+    '''
+    print tpl.format(using, sql, params)
+    #logger.debug(tpl, using, sql, params)
+
 class ModelBase(object):
     _auto_commit_  = True
     _using_        = 'default'
@@ -56,8 +67,8 @@ class Model(ModelBase):
     		_using = self._using_
     	if _using is None:
     		_using = 'default'
+        self._using = _using
 
-        self.logger = util.getLogger('.'.join((__name__, _using)))
     	_dns = pyar.settings.DNS.get(_using, None)
         if not _dns:
         	raise exc.DnsStringNotFoundError(
@@ -107,7 +118,7 @@ class Model(ModelBase):
 
     def _execute(self, sql, params, action=None):
         if self._debug_:
-            self.logger.debug("%s - %s", sql, params)
+            dumpSQL(sql, params, self._using)
         _cur    = self.db.getcur(self._conn)
         _dbname = None
         if hasattr(self, '_db_name_'):
@@ -145,7 +156,7 @@ class Model(ModelBase):
             return self._execute(sql[0], sql[1], 'insert')
         except Exception as e:
             if self._debug_:
-                self.logger.debug(e)
+                logger.debug(e)
             raise exc.DBOperationError("Database Operation Error.")
 
     def _select(self, sql, flag='select_all'):
@@ -153,7 +164,7 @@ class Model(ModelBase):
             return self._execute(sql[0], sql[1], flag)
         except Exception as e:
             if self._debug_:
-                self.logger.debug(e)
+                logger.debug(e)
             raise exc.DBOperationError("Database Operation Error.")
 
     def all(self, sql):
@@ -164,7 +175,7 @@ class Model(ModelBase):
             return result.Result.new(_res)
         except Exception as e:
             if self._debug_:
-                self.logger.debug(e)
+                logger.debug(e)
             raise exc.DBOperationError("Database Operation Error.")
 
     def first(self, sql):
@@ -175,7 +186,7 @@ class Model(ModelBase):
             return result.RowResult.new(_res)
         except Exception as e:
             if self._debug_:
-                self.logger.debug(e)
+                logger.debug(e)
             raise exc.DBOperationError("Database Operation Error.")
 
 
@@ -189,7 +200,7 @@ class Model(ModelBase):
             return 0
         except Exception as e:
             if self._debug_:
-                self.logger.debug(e)
+                logger.debug(e)
             raise exc.DBOperationError("Database Operation Error.")
 
     def update(self, sql):
@@ -198,7 +209,7 @@ class Model(ModelBase):
             return self._execute(sql[0], sql[1], 'update')
         except Exception as e:
             if self._debug_:
-                self.logger.debug(e)
+                logger.debug(e)
             raise exc.DBOperationError("Database Operation Error.")
 
     def delete(self, sql):
@@ -207,7 +218,7 @@ class Model(ModelBase):
             return self._execute(sql[0], sql[1], 'delete')
         except Exception as e:
             if self._debug_:
-                self.logger.debug(e)
+                logger.debug(e)
             raise exc.DBOperationError("Database Operation Error.")
 
     def end(self):
